==> piwigo-2.5.3.zip: piwigo/language/zh_HK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = '所有私有子相簿,設定為只允許私有觀看';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = '作為預防措施，以下插件已被停用。請檢查有沒有插件更新版本,然後再啟用它：';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = '作為預防措施，以下主題已被停用。請檢查有沒有主題更新版本,然後再啟用它：';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '在<i>%s</i>之前<b>?></b>，插入：';
$lang['Only administrator can run upgrade: please sign in below.'] = '只有管理員才能執行升級：請在下面登錄。';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = '只有縮圖的前綴和網站管理員的郵件地址可以從舊版設定中保存';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = '如果您遇到任何問題, 請執行維護檢查[管理>工具>維護]。';
$lang['SQL queries'] = 'SQL查詢';
$lang['Statistics'] = '統計';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = '本頁建議數據庫從舊的Piwigo版本升級到新版本。升級助手認為你正在運行的<strong>版本％s</strong>（或同等版本）。';
$lang['Upgrade'] = '升級';
$lang['Upgrade from version %s to %s'] = '從版本%s升級到%s';
$lang['Upgrade informations'] = '升級信息';
$lang['User permissions and group permissions have been erased'] = '使用者和群組的權限已被刪除';
$lang['You do not have access rights to run upgrade'] = '您沒有權限執行升級';
$lang['total SQL time'] = '總SQL執行時間';
$lang['total upgrade time'] = '總升級時間';
?>

==> piwigo-16.0.0.zip: piwigo/language/zh_HK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = '所有私有子相簿,設定為只允許私有觀看';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = '作為預防措施，以下插件已被停用。請檢查有沒有插件更新版本,然後再啟用它：';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = '作為預防措施，以下主題已被停用。請檢查有沒有主題更新版本,然後再啟用它：';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '在<i>%s</i>之前<b>?></b>，插入：';
$lang['Only administrator can run upgrade: please sign in below.'] = '只有管理員才能執行升級：請在下面登錄。';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = '只有縮圖的前綴和網站管理員的郵件地址可以從舊版設定中保存';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = '如果您遇到任何問題, 請執行維護檢查[管理>工具>維護]。';
$lang['SQL queries'] = 'SQL查詢';
$lang['Statistics'] = '統計';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = '本頁建議數據庫從舊的Piwigo版本升級到新版本。升級助手認為你正在運行的<strong>版本％s</strong>（或同等版本）。';
$lang['Upgrade'] = '升級';
$lang['Upgrade from version %s to %s'] = '從版本%s升級到%s';
$lang['Upgrade informations'] = '升級信息';
$lang['User permissions and group permissions have been erased'] = '使用者和群組的權限已被刪除';
$lang['You do not have access rights to run upgrade'] = '您沒有權限執行升級';
$lang['total SQL time'] = '總SQL執行時間';
$lang['total upgrade time'] = '總升級時間';
$lang['Discover what\'s new in Piwigo %s'] = '發現Piwigo %s的最新動態';
